@@ -147,6 +147,11 @@ class UserAPITestCase(BaseTestCase):
         response.connection.close()
         self.assertEqual(len(response.json()['items']), 2)
 
+    def test_options(self):
+        response = requests.options(self.base_url)
+        response.connection.close()
+        self.assertTrue(response.json()['corsEnabled'])
+
 
 # by now, our basic functions are tested, let's try something
 # better
